==> 0.0.1.tar.gz: lib/hyperkyc_doc_data.dart <==
import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:hyperkyc_flutter/hyperkyc_api_base_response.dart';

/// DocData contains document capture and OCR results based on no. of sides of the selected document
class DocData {
  final String? side;
  final String? docImagePath;
  final String? action;
  final String? responseHeaders;
  final DocCaptureApiDetail? responseResult;

  /// Constructor
  DocData({
    this.side,
    this.docImagePath,
    this.action,
    this.responseHeaders,
    this.responseResult,
  });

  /// Convert Map to DocData object
  Map<String, dynamic> toMap() {
    return {
      'side': this.side,
      'docImagePath': this.docImagePath,
      'action': this.action,
      'responseHeaders': this.responseHeaders,
      'responseResult': this.responseResult,
    };
  }

  /// Convert DocData object to Map
  factory DocData.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside DocData.fromMap');
    if (map.isEmpty) {
      return DocData();
    }
    return DocData(
      side: map['side'] as String?,
      docImagePath: map['docImagePath'] as String?,
      action: map['action'] as String?,
      responseHeaders: map['responseHeaders'] as String?,
      responseResult:
          DocCaptureApiDetail.fromMap(jsonDecode(map['responseResult']) ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'DocData{side: $side, docImagePath: $docImagePath, action: $action, responseHeaders: $responseHeaders, responseResult: $responseResult}';
  }
}

/// DocCaptureApiDetail is response body from the Hyperverge OCR API call
class DocCaptureApiDetail {
  final Metadata? metadata;
  final String? status;
  final String? statusCode;
  final DocResultObject? result;

  /// Constructor
  DocCaptureApiDetail({
    this.metadata,
    this.status,
    this.statusCode,
    this.result,
  });

  /// Convert DocCaptureApiDetail object to Map
  Map<String, dynamic> toMap() {
    return {
      'metadata': this.metadata,
      'status': this.status,
      'statusCode': this.statusCode,
      'result': this.result,
    };
  }

  /// Convert Map to DocCaptureApiDetail object
  factory DocCaptureApiDetail.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside DocCaptureApiDetail.fromMap');

    if (map.isEmpty) {
      return DocCaptureApiDetail();
    }
    return DocCaptureApiDetail(
      metadata: Metadata.fromMap(map['metadata'] ?? {}),
      status: map['status'] as String?,
      statusCode: map['statusCode'] as String?,
      result: DocResultObject.fromMap(map['result'] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'DocCaptureApiDetail{metadata: $metadata, status: $status, statusCode: $statusCode, result: $result}';
  }
}

/// DocResultObject
class DocResultObject {
  final List<OCRApiStructure?>? details;
  final String? error;
  final Summary? summary;

  /// Constructor
  DocResultObject({
    this.details,
    this.error,
    this.summary,
  });

  /// Convert DocResultObject object to Map
  Map<String, dynamic> toMap() {
    return {
      'details': this.details,
      'error': this.error,
      'summary': this.summary,
    };
  }

  /// Convert Map to DocResultObject object
  factory DocResultObject.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside DocResultObject.fromMap');

    if (map.isEmpty) {
      return DocResultObject();
    }
    List<OCRApiStructure> ocrApiStructureList = List.empty(growable: true);
    List details = map['details'] ?? [];
    if (details.isNotEmpty) {
      for (var detail in details) {
        OCRApiStructure ocrApiStructureDetail =
            OCRApiStructure.fromMap(detail ?? {});
        ocrApiStructureList.add(ocrApiStructureDetail);
      }
    }
    return DocResultObject(
      details: ocrApiStructureList,
      error: map['error'] as String?,
      summary: Summary.fromMap(map['summary'] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'DocResultObject{details: $details, error: $error, summary: $summary}';
  }
}

/// OCRApiStructure is the blueprint of response result details received from Hyperverge API call
class OCRApiStructure {
  final String? idType;
  final FieldsExtracted? fieldsExtracted;
  final DocQualityChecks? qualityChecks;
  final RuleChecks? ruleChecks;

  /// Constructor
  OCRApiStructure({
    this.idType,
    this.fieldsExtracted,
    this.qualityChecks,
    this.ruleChecks,
  });

  /// Convert OCRApiStructure object to Map
  Map<String, dynamic> toMap() {
    return {
      'idType': this.idType,
      'fieldsExtracted': this.fieldsExtracted,
      'qualityChecks': this.qualityChecks,
      'ruleChecks': this.ruleChecks,
    };
  }

  /// Convert Map to OCRApiStructure object
  factory OCRApiStructure.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside OCRApiStructure.fromMap');

    if (map.isEmpty) {
      return OCRApiStructure();
    }
    return OCRApiStructure(
      idType: map['idType'] as String?,
      fieldsExtracted: FieldsExtracted.fromMap(map['fieldsExtracted'] ?? {}),
      qualityChecks: DocQualityChecks.fromMap(map['qualityChecks'] ?? {}),
      ruleChecks: RuleChecks.fromMap(map['ruleChecks'] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'OCRApiStructure{idType: $idType, fieldsExtracted: $fieldsExtracted, qualityChecks: $qualityChecks, ruleChecks: $ruleChecks}';
  }
}

/// FieldsExtracted from the response received from Hyperverge API call
class FieldsExtracted {
  final Fieldvalue? idNumber;
  final Fieldvalue? firstName;
  final Fieldvalue? middleName;
  final Fieldvalue? lastName;
  final Fieldvalue? fullName;
  final Fieldvalue? dateOfBirth;
  final Fieldvalue? dateOfIssue;
  final Fieldvalue? dateOfExpiry;
  final Fieldvalue? countryCode;
  final Fieldvalue? type;
  final Fieldvalue? gender;
  final Fieldvalue? placeOfBirth;
  final Fieldvalue? placeOfIssue;
  final YearOfBirthFieldValue? yearOfBirth;
  final Fieldvalue? age;
  final Fieldvalue? fatherName;
  final Fieldvalue? motherName;
  final Fieldvalue? husbandName;
  final Fieldvalue? spouseName;
  final Fieldvalue? nationality;
  final Fieldvalue? mrzString;
  final Fieldvalue? hometown;
  final Address? address;

  /// Constructor
  FieldsExtracted({
    this.idNumber,
    this.firstName,
    this.middleName,
    this.lastName,
    this.fullName,
    this.dateOfBirth,
    this.dateOfIssue,
    this.dateOfExpiry,
    this.countryCode,
    this.type,
    this.gender,
    this.placeOfBirth,
    this.placeOfIssue,
    this.yearOfBirth,
    this.age,
    this.fatherName,
    this.motherName,
    this.husbandName,
    this.spouseName,
    this.nationality,
    this.mrzString,
    this.hometown,
    this.address,
  });

  /// Convert FieldsExtracted object to Map
  Map<String, dynamic> toMap() {
    return {
      'idNumber': this.idNumber,
      'firstName': this.firstName,
      'middleName': this.middleName,
      'lastName': this.lastName,
      'fullName': this.fullName,
      'dateOfBirth': this.dateOfBirth,
      'dateOfIssue': this.dateOfIssue,
      'dateOfExpiry': this.dateOfExpiry,
      'countryCode': this.countryCode,
      'type': this.type,
      'gender': this.gender,
      'placeOfBirth': this.placeOfBirth,
      'placeOfIssue': this.placeOfIssue,
      'yearOfBirth': this.yearOfBirth,
      'age': this.age,
      'fatherName': this.fatherName,
      'motherName': this.motherName,
      'husbandName': this.husbandName,
      'spouseName': this.spouseName,
      'nationality': this.nationality,
      'mrzString': this.mrzString,
      'hometown': this.hometown,
      'address': this.address,
    };
  }

  /// Convert Map to FieldsExtracted object
  factory FieldsExtracted.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside FieldsExtracted.fromMap');

    if (map.isEmpty) {
      return FieldsExtracted();
    }
    return FieldsExtracted(
      idNumber: Fieldvalue.fromMap(map['idNumber'] ?? {}),
      firstName: Fieldvalue.fromMap(map['firstName'] ?? {}),
      middleName: Fieldvalue.fromMap(map['middleName'] ?? {}),
      lastName: Fieldvalue.fromMap(map['lastName'] ?? {}),
      fullName: Fieldvalue.fromMap(map['fullName'] ?? {}),
      dateOfBirth: Fieldvalue.fromMap(map['dateOfBirth'] ?? {}),
      dateOfIssue: Fieldvalue.fromMap(map['dateOfIssue'] ?? {}),
      dateOfExpiry: Fieldvalue.fromMap(map['dateOfExpiry'] ?? {}),
      countryCode: Fieldvalue.fromMap(map['countryCode'] ?? {}),
      type: Fieldvalue.fromMap(map['type'] ?? {}),
      gender: Fieldvalue.fromMap(map['gender'] ?? {}),
      placeOfBirth: Fieldvalue.fromMap(map['placeOfBirth'] ?? {}),
      placeOfIssue: Fieldvalue.fromMap(map['placeOfIssue'] ?? {}),
      yearOfBirth: YearOfBirthFieldValue.fromMap(map['yearOfBirth'] ?? {}),
      age: Fieldvalue.fromMap(map['age'] ?? {}),
      fatherName: Fieldvalue.fromMap(map['fatherName'] ?? {}),
      motherName: Fieldvalue.fromMap(map['motherName'] ?? {}),
      husbandName: Fieldvalue.fromMap(map['husbandName'] ?? {}),
      spouseName: Fieldvalue.fromMap(map['spouseName'] ?? {}),
      nationality: Fieldvalue.fromMap(map['nationality'] ?? {}),
      mrzString: Fieldvalue.fromMap(map['mrzString'] ?? {}),
      hometown: Fieldvalue.fromMap(map['hometown'] ?? {}),
      address: Address.fromMap(map['address'] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'FieldsExtracted{idNumber: $idNumber, firstName: $firstName, middleName: $middleName, lastName: $lastName, fullName: $fullName, dateOfBirth: $dateOfBirth, dateOfIssue: $dateOfIssue, dateOfExpiry: $dateOfExpiry, countryCode: $countryCode, type: $type, gender: $gender, placeOfBirth: $placeOfBirth, placeOfIssue: $placeOfIssue, yearOfBirth: $yearOfBirth, age: $age, fatherName: $fatherName, motherName: $motherName, husbandName: $husbandName, spouseName: $spouseName, nationality: $nationality, mrzString: $mrzString, hometown: $hometown, address: $address}';
  }
}

/// YearOfBirthFieldValue
class YearOfBirthFieldValue {
  final String? value;
  final String? confidence;
  final String? score;
  final String? reviewNeeded;

  /// Constructor
  YearOfBirthFieldValue({
    this.value,
    this.confidence,
    this.score,
    this.reviewNeeded,
  });

  /// Convert YearOfBirthFieldValue object to Map
  Map<String, dynamic> toMap() {
    return {
      'value': this.value,
      'confidence': this.confidence,
      'score': this.score,
      'reviewNeeded': this.reviewNeeded,
    };
  }

  /// Convert Map to YearOfBirthFieldValue object
  factory YearOfBirthFieldValue.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside YearOfBirthFieldValue.fromMap');

    if (map.isEmpty) {
      return YearOfBirthFieldValue();
    }
    return YearOfBirthFieldValue(
      value: map['value'] as String?,
      confidence: map['confidence'] as String?,
      score: map['score'] as String?,
      reviewNeeded: map['reviewNeeded'] as String?,
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'YearOfBirthFieldValue{value: $value, confidence: $confidence, score: $score, reviewNeeded: $reviewNeeded}';
  }
}

/// Address holds the properties of Address received from Hyperverge API call
class Address {
  final String? value;
  final String? confidence;
  final String? score;
  final String? houseNumber;
  final String? additionalInfo;
  final String? province;
  final String? district;
  final String? street;
  final String? zipCode;

  /// Constructor
  Address({
    this.value,
    this.confidence,
    this.score,
    this.houseNumber,
    this.additionalInfo,
    this.province,
    this.district,
    this.street,
    this.zipCode,
  });

  /// Convert Address object to Map
  Map<String, dynamic> toMap() {
    return {
      'value': this.value,
      'confidence': this.confidence,
      'score': this.score,
      'houseNumber': this.houseNumber,
      'additionalInfo': this.additionalInfo,
      'province': this.province,
      'district': this.district,
      'street': this.street,
      'zipCode': this.zipCode,
    };
  }

  /// Convert Map to Address object
  factory Address.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside Address.fromMap');

    if (map.isEmpty) {
      return Address();
    }
    return Address(
      value: map['value'] as String?,
      confidence: map['confidence'] as String?,
      score: map['score'] as String?,
      houseNumber: map['houseNumber'] as String?,
      additionalInfo: map['additionalInfo'] as String?,
      province: map['province'] as String?,
      district: map['district'] as String?,
      street: map['street'] as String?,
      zipCode: map['zipCode'] as String?,
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'Address{value: $value, confidence: $confidence, score: $score, houseNumber: $houseNumber, additionalInfo: $additionalInfo, province: $province, district: $district, street: $street, zipCode: $zipCode}';
  }
}

/// DocQualityChecks
class DocQualityChecks {
  final Fieldvalue? blur;

  /// Constructor
  DocQualityChecks({
    this.blur,
  });

  /// Convert DocQualityChecks object to Map
  Map<String, dynamic> toMap() {
    return {
      'blur': this.blur,
    };
  }

  /// Convert Map to DocQualityChecks object
  factory DocQualityChecks.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside DocQualityChecks.fromMap');

    if (map.isEmpty) {
      return DocQualityChecks();
    }
    return DocQualityChecks(
      blur: Fieldvalue.fromMap(map['blur'] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'DocQualityChecks{blur: $blur}';
  }
}

/// RuleChecks
class RuleChecks {
  final Fieldvalue? idNumberInvalid;

  /// Constructor
  RuleChecks({
    this.idNumberInvalid,
  });

  ///  Convert RuleChecks object to Map
  Map<String, dynamic> toMap() {
    return {
      'idNumberInvalid': this.idNumberInvalid,
    };
  }

  /// Convert Map to RuleChecks object
  factory RuleChecks.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside RuleChecks.fromMap');

    if (map.isEmpty) {
      return RuleChecks();
    }
    return RuleChecks(
      idNumberInvalid: Fieldvalue.fromMap(map['idNumberInvalid'] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'RuleChecks{idNumberInvalid: $idNumberInvalid}';
  }
}

==> 0.0.2.tar.gz: lib/hyperkyc_doc_data.dart <==
import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:hyperkyc_flutter/hyperkyc_api_base_response.dart';

/// DocData contains document capture and OCR results based on no. of sides of the selected document
class DocData {
  /// Document side - front / back
  final String? side;

  /// File path to the captured document image
  final String? docImagePath;

  /// Action - pass / manualReview / fail
  final String? action;

  /// Response headers (json string) from OCR API
  final String? responseHeaders;

  /// Response body from the OCR API
  final DocCaptureApiDetail? responseResult;

  /// Constructor
  DocData({
    this.side,
    this.docImagePath,
    this.action,
    this.responseHeaders,
    this.responseResult,
  });

  /// Convert Map to DocData object
  Map<String, dynamic> toMap() {
    return {
      'side': this.side,
      'docImagePath': this.docImagePath,
      'action': this.action,
      'responseHeaders': this.responseHeaders,
      'responseResult': this.responseResult,
    };
  }

  /// Convert DocData object to Map
  factory DocData.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside DocData.fromMap');
    if (map.isEmpty) {
      return DocData();
    }
    return DocData(
      side: map['side'] as String?,
      docImagePath: map['docImagePath'] as String?,
      action: map['action'] as String?,
      responseHeaders: map['responseHeaders'] as String?,
      responseResult:
          DocCaptureApiDetail.fromMap(jsonDecode(map['responseResult']) ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'DocData{side: $side, docImagePath: $docImagePath, action: $action, responseHeaders: $responseHeaders, responseResult: $responseResult}';
  }
}

/// DocCaptureApiDetail is response body from the Hyperverge OCR API call
class DocCaptureApiDetail {
  /// Metadata contains data like TransactionId, RequestId, Attempts count, etc
  final Metadata? metadata;

  /// Status received after Hyperverge API call
  final String? status;

  /// StatusCode received after Hyperverge API call
  final String? statusCode;

  /// DocResultObject
  final DocResultObject? result;

  /// Constructor
  DocCaptureApiDetail({
    this.metadata,
    this.status,
    this.statusCode,
    this.result,
  });

  /// Convert DocCaptureApiDetail object to Map
  Map<String, dynamic> toMap() {
    return {
      'metadata': this.metadata,
      'status': this.status,
      'statusCode': this.statusCode,
      'result': this.result,
    };
  }

  /// Convert Map to DocCaptureApiDetail object
  factory DocCaptureApiDetail.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside DocCaptureApiDetail.fromMap');

    if (map.isEmpty) {
      return DocCaptureApiDetail();
    }
    return DocCaptureApiDetail(
      metadata: Metadata.fromMap(map['metadata'] ?? {}),
      status: map['status'] as String?,
      statusCode: (map['statusCode'] ?? '').toString(),
      result: DocResultObject.fromMap(map['result'] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'DocCaptureApiDetail{metadata: $metadata, status: $status, statusCode: $statusCode, result: $result}';
  }
}

/// DocResultObject
class DocResultObject {
  /// List of details present in OCR result
  final List<OCRApiStructure?>? details;

  /// Error
  final String? error;

  /// Summary present in OCR result
  final Summary? summary;

  /// Constructor
  DocResultObject({
    this.details,
    this.error,
    this.summary,
  });

  /// Convert DocResultObject object to Map
  Map<String, dynamic> toMap() {
    return {
      'details': this.details,
      'error': this.error,
      'summary': this.summary,
    };
  }

  /// Convert Map to DocResultObject object
  factory DocResultObject.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside DocResultObject.fromMap');

    if (map.isEmpty) {
      return DocResultObject();
    }
    List<OCRApiStructure> ocrApiStructureList = List.empty(growable: true);
    List details = map['details'] ?? [];
    if (details.isNotEmpty) {
      for (var detail in details) {
        OCRApiStructure ocrApiStructureDetail =
            OCRApiStructure.fromMap(detail ?? {});
        ocrApiStructureList.add(ocrApiStructureDetail);
      }
    }
    return DocResultObject(
      details: ocrApiStructureList,
      error: map['error'] as String?,
      summary: Summary.fromMap(map['summary'] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'DocResultObject{details: $details, error: $error, summary: $summary}';
  }
}

/// OCRApiStructure is the blueprint of response result details received from Hyperverge API call
class OCRApiStructure {
  /// idType : PAN / Aadhaar / Social Security Card / Passport etc
  final String? idType;

  /// FieldsExtracted
  final FieldsExtracted? fieldsExtracted;

  /// DocQualityChecks
  final DocQualityChecks? qualityChecks;

  /// RuleChecks
  final RuleChecks? ruleChecks;

  /// Constructor
  OCRApiStructure({
    this.idType,
    this.fieldsExtracted,
    this.qualityChecks,
    this.ruleChecks,
  });

  /// Convert OCRApiStructure object to Map
  Map<String, dynamic> toMap() {
    return {
      'idType': this.idType,
      'fieldsExtracted': this.fieldsExtracted,
      'qualityChecks': this.qualityChecks,
      'ruleChecks': this.ruleChecks,
    };
  }

  /// Convert Map to OCRApiStructure object
  factory OCRApiStructure.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside OCRApiStructure.fromMap');

    if (map.isEmpty) {
      return OCRApiStructure();
    }
    return OCRApiStructure(
      idType: map['idType'] as String?,
      fieldsExtracted: FieldsExtracted.fromMap(map['fieldsExtracted'] ?? {}),
      qualityChecks: DocQualityChecks.fromMap(map['qualityChecks'] ?? {}),
      ruleChecks: RuleChecks.fromMap(map['ruleChecks'] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'OCRApiStructure{idType: $idType, fieldsExtracted: $fieldsExtracted, qualityChecks: $qualityChecks, ruleChecks: $ruleChecks}';
  }
}

/// FieldsExtracted from the response received from Hyperverge API call
class FieldsExtracted {
  /// idNumber extracted from the document
  final Fieldvalue? idNumber;

  /// FirstName extracted from the document
  final Fieldvalue? firstName;

  /// MiddleName extracted from the document
  final Fieldvalue? middleName;

  /// LastName extracted from the document
  final Fieldvalue? lastName;

  /// FullName extracted from the document
  final Fieldvalue? fullName;

  /// Date of birth extracted from the document
  final Fieldvalue? dateOfBirth;

  /// Date of issue extracted from the document
  final Fieldvalue? dateOfIssue;

  /// Date of expiry extracted from the document
  final Fieldvalue? dateOfExpiry;

  /// Country Code extracted from the document
  final Fieldvalue? countryCode;

  /// Type extracted from the document
  final Fieldvalue? type;

  /// Gender extracted from the document
  final Fieldvalue? gender;

  /// Place of birth extracted from the document
  final Fieldvalue? placeOfBirth;

  /// Place of issue extracted from the document
  final Fieldvalue? placeOfIssue;

  /// Year of birth extracted from the document
  final Fieldvalue? yearOfBirth;

  /// Age extracted from the document
  final Fieldvalue? age;

  /// FatherName extracted from the document
  final Fieldvalue? fatherName;

  /// MotherName extracted from the document
  final Fieldvalue? motherName;

  /// HusbandName extracted from the document
  final Fieldvalue? husbandName;

  /// SpouseName extracted from the document
  final Fieldvalue? spouseName;

  /// Nationality extracted from the document
  final Fieldvalue? nationality;

  /// MRZ String extracted from the document
  final Fieldvalue? mrzString;

  /// Hometown extracted from the document
  final Fieldvalue? hometown;

  /// Address extracted from the document
  final Address? address;

  /// Constructor
  FieldsExtracted({
    this.idNumber,
    this.firstName,
    this.middleName,
    this.lastName,
    this.fullName,
    this.dateOfBirth,
    this.dateOfIssue,
    this.dateOfExpiry,
    this.countryCode,
    this.type,
    this.gender,
    this.placeOfBirth,
    this.placeOfIssue,
    this.yearOfBirth,
    this.age,
    this.fatherName,
    this.motherName,
    this.husbandName,
    this.spouseName,
    this.nationality,
    this.mrzString,
    this.hometown,
    this.address,
  });

  /// Convert FieldsExtracted object to Map
  Map<String, dynamic> toMap() {
    return {
      'idNumber': this.idNumber,
      'firstName': this.firstName,
      'middleName': this.middleName,
      'lastName': this.lastName,
      'fullName': this.fullName,
      'dateOfBirth': this.dateOfBirth,
      'dateOfIssue': this.dateOfIssue,
      'dateOfExpiry': this.dateOfExpiry,
      'countryCode': this.countryCode,
      'type': this.type,
      'gender': this.gender,
      'placeOfBirth': this.placeOfBirth,
      'placeOfIssue': this.placeOfIssue,
      'yearOfBirth': this.yearOfBirth,
      'age': this.age,
      'fatherName': this.fatherName,
      'motherName': this.motherName,
      'husbandName': this.husbandName,
      'spouseName': this.spouseName,
      'nationality': this.nationality,
      'mrzString': this.mrzString,
      'hometown': this.hometown,
      'address': this.address,
    };
  }

  /// Convert Map to FieldsExtracted object
  factory FieldsExtracted.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside FieldsExtracted.fromMap');

    if (map.isEmpty) {
      return FieldsExtracted();
    }
    return FieldsExtracted(
      idNumber: Fieldvalue.fromMap(map['idNumber'] ?? {}),
      firstName: Fieldvalue.fromMap(map['firstName'] ?? {}),
      middleName: Fieldvalue.fromMap(map['middleName'] ?? {}),
      lastName: Fieldvalue.fromMap(map['lastName'] ?? {}),
      fullName: Fieldvalue.fromMap(map['fullName'] ?? {}),
      dateOfBirth: Fieldvalue.fromMap(map['dateOfBirth'] ?? {}),
      dateOfIssue: Fieldvalue.fromMap(map['dateOfIssue'] ?? {}),
      dateOfExpiry: Fieldvalue.fromMap(map['dateOfExpiry'] ?? {}),
      countryCode: Fieldvalue.fromMap(map['countryCode'] ?? {}),
      type: Fieldvalue.fromMap(map['type'] ?? {}),
      gender: Fieldvalue.fromMap(map['gender'] ?? {}),
      placeOfBirth: Fieldvalue.fromMap(map['placeOfBirth'] ?? {}),
      placeOfIssue: Fieldvalue.fromMap(map['placeOfIssue'] ?? {}),
      yearOfBirth: Fieldvalue.fromMap(map['yearOfBirth'] ?? {}),
      age: Fieldvalue.fromMap(map['age'] ?? {}),
      fatherName: Fieldvalue.fromMap(map['fatherName'] ?? {}),
      motherName: Fieldvalue.fromMap(map['motherName'] ?? {}),
      husbandName: Fieldvalue.fromMap(map['husbandName'] ?? {}),
      spouseName: Fieldvalue.fromMap(map['spouseName'] ?? {}),
      nationality: Fieldvalue.fromMap(map['nationality'] ?? {}),
      mrzString: Fieldvalue.fromMap(map['mrzString'] ?? {}),
      hometown: Fieldvalue.fromMap(map['hometown'] ?? {}),
      address: Address.fromMap(map['address'] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'FieldsExtracted{idNumber: $idNumber, firstName: $firstName, middleName: $middleName, lastName: $lastName, fullName: $fullName, dateOfBirth: $dateOfBirth, dateOfIssue: $dateOfIssue, dateOfExpiry: $dateOfExpiry, countryCode: $countryCode, type: $type, gender: $gender, placeOfBirth: $placeOfBirth, placeOfIssue: $placeOfIssue, yearOfBirth: $yearOfBirth, age: $age, fatherName: $fatherName, motherName: $motherName, husbandName: $husbandName, spouseName: $spouseName, nationality: $nationality, mrzString: $mrzString, hometown: $hometown, address: $address}';
  }
}

/// Address holds the properties of Address received from Hyperverge API call
class Address {
  /// Value
  final String? value;

  /// Confidence
  final String? confidence;

  /// Confidence score
  final String? score;

  /// House Number
  final String? houseNumber;

  /// Additional info
  final String? additionalInfo;

  /// Province
  final String? province;

  /// District
  final String? district;

  /// Street
  final String? street;

  /// Zipcode
  final String? zipCode;

  /// Constructor
  Address({
    this.value,
    this.confidence,
    this.score,
    this.houseNumber,
    this.additionalInfo,
    this.province,
    this.district,
    this.street,
    this.zipCode,
  });

  /// Convert Address object to Map
  Map<String, dynamic> toMap() {
    return {
      'value': this.value,
      'confidence': this.confidence,
      'score': this.score,
      'houseNumber': this.houseNumber,
      'additionalInfo': this.additionalInfo,
      'province': this.province,
      'district': this.district,
      'street': this.street,
      'zipCode': this.zipCode,
    };
  }

  /// Convert Map to Address object
  factory Address.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside Address.fromMap');

    if (map.isEmpty) {
      return Address();
    }
    return Address(
      value: map['value'] as String?,
      confidence: map['confidence'] as String?,
      score: map['score'] as String?,
      houseNumber: map['houseNumber'] as String?,
      additionalInfo: map['additionalInfo'] as String?,
      province: map['province'] as String?,
      district: map['district'] as String?,
      street: map['street'] as String?,
      zipCode: map['zipCode'] as String?,
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'Address{value: $value, confidence: $confidence, score: $score, houseNumber: $houseNumber, additionalInfo: $additionalInfo, province: $province, district: $district, street: $street, zipCode: $zipCode}';
  }
}

/// DocQualityChecks
class DocQualityChecks {
  /// Blur check
  final Fieldvalue? blur;

  /// Constructor
  DocQualityChecks({
    this.blur,
  });

  /// Convert DocQualityChecks object to Map
  Map<String, dynamic> toMap() {
    return {
      'blur': this.blur,
    };
  }

  /// Convert Map to DocQualityChecks object
  factory DocQualityChecks.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside DocQualityChecks.fromMap');

    if (map.isEmpty) {
      return DocQualityChecks();
    }
    return DocQualityChecks(
      blur: Fieldvalue.fromMap(map['blur'] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'DocQualityChecks{blur: $blur}';
  }
}

/// RuleChecks
class RuleChecks {
  /// id number invalid check
  final Fieldvalue? idNumberInvalid;

  /// Constructor
  RuleChecks({
    this.idNumberInvalid,
  });

  ///  Convert RuleChecks object to Map
  Map<String, dynamic> toMap() {
    return {
      'idNumberInvalid': this.idNumberInvalid,
    };
  }

  /// Convert Map to RuleChecks object
  factory RuleChecks.fromMap(Map<dynamic, dynamic> map) {
    debugPrint('inside RuleChecks.fromMap');

    if (map.isEmpty) {
      return RuleChecks();
    }
    return RuleChecks(
      idNumberInvalid: Fieldvalue.fromMap(map['idNumberInvalid'] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'RuleChecks{idNumberInvalid: $idNumberInvalid}';
  }
}
